<?php

namespace Drupal\social_graphql\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\social_graphql\Services\Facebook\FacebookPostCollector;
use Drupal\social_graphql\Services\SocialGraphQlManager;

/**
 * Class FacebookSettingsForm.
 *
 * @package Drupal\social_graphql\Form
 */
class FacebookSettingsForm extends SocialGraphQlSettingsFormBase {

  /**
   * @var \Drupal\social_graphql\Services\Facebook\FacebookPostCollector
   */
  protected $facebookService;


  const SOCIAL_NETWORK = 'facebook';

  /**
   * Constructs a new GenerateExampleForm object.
   *
   * {@inheritdoc}
   */
  public function __construct(ConfigFactoryInterface $config_factory, FacebookPostCollector $facebook_post_collector, SocialGraphQlManager $social_graphQl_manager) {
    parent::__construct($config_factory, $facebook_post_collector, $social_graphQl_manager);
    $this->facebookService = $facebook_post_collector;
  }

  public static function getSociaNetwork() {
    return self::SOCIAL_NETWORK;
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'social_graphql.facebook',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'facebook_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('social_graphql.facebook');
    $form['page_name'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Default Facebook Page Name'),
      '#default_value' => $config->get('page_name'),
      '#description' => $this->t('eg. If your Facebook page URL is this http://www.facebook.com/YOUR_PAGE_NAME, <br />then you just need to add this YOUR_PAGE_NAME above.'),
      '#size' => 60,
      '#maxlength' => 100,
      '#required' => TRUE,
    ];
    $form['app_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Default Facebook App ID'),
      '#default_value' => $config->get('app_id'),
      '#size' => 60,
      '#maxlength' => 255,
      '#required' => TRUE,
    ];
    $form['secret_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Default Facebook Secret Key'),
      '#default_value' => $config->get('secret_key'),
      '#size' => 60,
      '#maxlength' => 255,
      '#required' => TRUE,
    ];

    $form['access_token'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Default Facebook User Token'),
      '#default_value' => $config->get('access_token'),
      '#size' => 60,
      '#maxlength' => 255,
      '#required' => TRUE,
      '#prefix' => '<div id="ajax-access-token">',
      '#suffix' => '</div>',
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * @todo
   * @param array $form
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *
   * @return mixed
   * @throws \GuzzleHttp\Exception\GuzzleException
   */
  public function generateToken(array &$form, FormStateInterface $form_state) {
    $access_token = $this->facebookService->getAccessToken($form_state->getValue('app_id'), $form_state->getValue('secret_key'));

    if (!empty($access_token->access_token)) {

      $config = $this->config('social_graphql.facebook');
      $config->set('access_token', $access_token->access_token);
      $config->save();
    }
    return $form['access_token'];
  }



}
