<?php

namespace Drupal\social_graphql\Plugin\Deriver;

use Drupal\Component\Plugin\Derivative\DeriverBase;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Plugin\Discovery\ContainerDeriverInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\graphql\Utility\StringHelper;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\Yaml\Yaml;

/**
 * Derives content entity fields as GraphQL fields.
 */
abstract class SocialGraphQLPostDeriverBase extends DeriverBase implements SocialGraphQLPostDeriverInterface, ContainerDeriverInterface {

  use StringTranslationTrait;

  /**
   * Internal path for the mapping.
   */
  const PATH_MAPPING = '/src/Mapping';

  protected $moduleHandler;

  /**
   * {@inheritDoc}
   */
  public function __construct(ModuleHandlerInterface $module_handler) {
    $this->moduleHandler = $module_handler;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, $basePluginId) {
    // Instantiates this form class.
    return new static(
    // Load the service required to construct this class.
      $container->get('module_handler')
    );
  }


  // @todo get it from graphql
  /**
   * @return array
   */
  protected function getGraphQLBaseType() {
    return ['String', 'String!', 'Int', 'Boolean', 'ID'];
  }

  /**
   * {@inheritdoc}
   */
  public function getDerivativeDefinitions($base_plugin_definition) {
    if (!empty($base_plugin_definition['social_gql_object'])) {
      $mapping = $this->getMapping($base_plugin_definition['social_gql_object']);
      if (!empty($mapping)) {
        $this->generateDeriver($base_plugin_definition, $mapping);
      }
      else {
        throw new \Exception($this->t('No mapping found for social graphql :social :field', [
          ':social' => $this->getSociaNetwork(),
          ':field' => $base_plugin_definition['social_gql_object'],
        ]));
      }
    }
    return parent::getDerivativeDefinitions($base_plugin_definition);
  }

  /**
   * {@inheritdoc}
   */
  public function generateDeriver($base_plugin_definition, array $mapping) {
    foreach ($mapping as $field_name => $type) {
      $derived_id = 'social_graphql.' . $this->getSociaNetwork() . '.' . $base_plugin_definition['social_gql_object'] . ':';
      $derived_id .= $field_name;
      $this->derivatives[$derived_id] = [
        'name' => StringHelper::propCase($field_name),
        'type' => $type,
        'field_name' => $field_name,
      ];
      $this->derivatives[$derived_id] = $this->derivatives[$derived_id] + $base_plugin_definition;
    }
  }

  /**
   * Return the mapping to the REST azure API.
   *
   * @param string $trigger_type.
   *   Trigger type of azure.
   *
   * @return bool|array
   *   The content of mapping, or FALSE if there are no mapping.
   */
  public function getMapping($social_object_type) {
    $filename = $social_object_type . '.yml';
    $module_path = $this->moduleHandler->getModule('social_graphql')
        ->getPath() . self::PATH_MAPPING . '/' . $this->getSociaNetwork();
    $files = file_scan_directory($module_path, '/^' . $social_object_type . '.*\.yml$/i', ['recurse' => 1]);

    // Search file with view mode.
    foreach ($files as $file) {
      if ($file->filename == $filename) {
        return Yaml::parse(file_get_contents($file->uri));
      }
    }
    return FALSE;
  }

}
