<?php

namespace Drupal\social_graphql\Plugin\GraphQL\Fields\Facebook;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\graphql\GraphQL\Execution\ResolveContext;
use Drupal\graphql\Plugin\GraphQL\Fields\FieldPluginBase;
use Drupal\social_graphql\Services\Facebook\FacebookPostCollector;
use GraphQL\Error\Error;
use GraphQL\Type\Definition\ResolveInfo;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Retrieve a link fields route object.
 *
 * @GraphQLField(
 *   id = "social_graphql_facebook",
 *   secure = true,
 *   name = "socialGraphQLFacebook",
 *   type = "[SocialGraphQLFacebookPost]",
 *   arguments = {
 *     "user_id" = "String",
 *     "count" = "Int",
 *     "screen_name" = "String",
 *     "exclude_replies" = "Boolean",
 *     "include_rts" = "Boolean"
 *   }
 * )
 */
class SocialGraphQLFacebook extends FieldPluginBase implements ContainerFactoryPluginInterface {

  /**
   * The Facebook service.
   *
   * @var \Drupal\social_graphql\Services\FacebookPostCollector
   */
  protected $facebookService;

  /**
   * Config factory.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected $config;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $pluginId, $pluginDefinition) {
    return new static(
      $configuration,
      $pluginId,
      $pluginDefinition,
      $container->get('social_graphql.facebook'),
      $container->get('config.factory')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function __construct(array $configuration, $pluginId, $pluginDefinition, FacebookPostCollector $social_graphql_facebook, ConfigFactoryInterface $config_factory) {
    parent::__construct($configuration, $pluginId, $pluginDefinition);
    $this->facebookService = $social_graphql_facebook;
    $this->config = $config_factory->get('social_graphql.facebook');
  }

  /**
   * {@inheritdoc}
   */
  public function resolveValues($value, array $args, ResolveContext $context, ResolveInfo $info) {
    $post_types = $this->config->get('all_types');
    if (!$post_types) {
      $post_types = $this->config->get('post_type');
    }
    $this->facebookService->getPosts(   $this->config->get('page_name'),
      $post_types,
      $this->config->get('no_feeds')
    );
    if ($posts->errors) {
      foreach ($posts->errors as $error) {
        if ($error->message) {
          throw new Error(sprintf("%s", $error->message));
        }
      }
    }
    // Empty posts.
    if (empty($posts)) {
      yield   [
        'type' => 'SocialGraphQLFacebookPost',
        'post' => '',
      ];
    }
    // Fetch all posts.
    foreach ($posts as $post) {
      yield  [
        'type' => 'SocialGraphQLFacebookPost',
        'post' => $post,
      ];
    }
  }

}
