<?php

namespace Drupal\social_graphql\Plugin\GraphQL\Fields\Facebook;

use Drupal\graphql\GraphQL\Execution\ResolveContext;
use Drupal\graphql\Plugin\GraphQL\Fields\FieldPluginBase;
use GraphQL\Type\Definition\ResolveInfo;

/**
 * @GraphQLField(
 *   id = "social_graphql_facebook_post_fields",
 *   secure = true,
 *   name = "socialGraphQLFacebookPostFields",
 *   parents = {"SocialGraphQLFacebookPost"},
 *   social_gql_object = "post",
 *   deriver =
 *   "Drupal\social_graphql\Plugin\Deriver\Facebook\SocialGraphQlFacebookFieldsDeriver"
 * )
 */
class SocialGraphQLFacebookPostField extends FieldPluginBase {

  /**
   * {@inheritdoc}
   */
  public function resolveValues($value, array $args, ResolveContext $context, ResolveInfo $info) {
    // If user is request, get user into the post.
    if ($info->parentType->name == 'SocialGraphQLFacebookPost' && $info->returnType->name == 'SocialGraphQLFacebookUser') {
      if (!empty($value['post']->user)) {

        yield  [
          'type' => 'SocialGraphQLFacebookUser',
          'user' => $value['post']->user,
        ];
      }
      else {
        // Empty user.
        yield  [
          'type' => 'SocialGraphQLFacebookUser',
          'user' => '',
        ];
      }
    }
    else {
      // Get the field value.
      $definition = $this->getPluginDefinition();
      if (!empty($value['post']->{$definition['field_name']})) {
        yield $value['post']->{$definition['field_name']};
      }
      else {
        yield '';
      }
    }


  }

}
